@@ -108,7 +108,14 @@ def csvPreprocess(csv_folder, csv_folder_cleaned, csv_folder_encoding):
 
     csvEncoder(csv_folder, csv_folder_encoding)
     csvCleaner(csv_folder_encoding, csv_folder_cleaned)
-    
+
+def unicodeProcess(dataframe):
+    dataframe['title'] = dataframe['title'].str.replace('â', '')
+    dataframe['title'] = dataframe['title'].str.replace('Â', '')
+    dataframe['title'] = dataframe['title'].str.replace('fã¼r', 'for')
+    dataframe['title'] = dataframe['title'].str.replace('ã', '')
+    dataframe['title'] = dataframe['title'].str.replace(' ', ' ')
+
 
 def csvImporter_NEW(csv_folder_cleaned, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
@@ -122,8 +129,7 @@ def csvImporter_NEW(csv_folder_cleaned, keyword_pool):
         
         dataframe['brand'] = dataframe['brand'].str.lower()
         dataframe['title'] = dataframe['title'].str.lower()
-        dataframe['title'] = dataframe['title'].str.replace('â', '')
-        dataframe['title'] = dataframe['title'].str.replace('Â', '')
+        unicodeProcess(dataframe)
 
         ##### no pool
         if "Laptops" in fileList[i]:
@@ -170,10 +176,7 @@ def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool):
 
         dataframe['brand'] = dataframe['brand'].str.lower()
         dataframe['title'] = dataframe['title'].str.lower()
-        dataframe['title'] = dataframe['title'].str.replace('â', '')
-        dataframe['title'] = dataframe['title'].str.replace('Â', '')
-        dataframe['title'] = dataframe['title'].str.replace('fã¼r', 'for')
-        dataframe['title'] = dataframe['title'].str.replace('ã', '')
+        unicodeProcess(dataframe)
 
         check_frame = dataframe[['brand', 'title', 'units_sold', 'retail_sales']].groupby(by=['brand', 'title'], as_index=False).sum()
 
